# Using Quarto for Scientific Publications

[Quarto](https://quarto.org) describes itself as *an open-source scientific and technical publication system*.

It makes use of [Pandoc](https://pandoc.org) to convert  Pandoc-compatible markdown into books, articles, presentations, websites or other formats.
In addition, Quarto includes easy use of equations, citations, and references as we are all used to from LaTex.

Even this readme can be converted into a PDF with Quarto:

```
quarto render example.qmd --to pdf
```


# VS Code Setup

Several helpful plugins exist for VS Code covering the most important steps when creating a Document.

My setup makes use of the following Plugins:

- [General Quarto Support](https://marketplace.visualstudio.com/items?itemName=quarto.quarto)
- [Draw.io (Creating SVGs)](https://marketplace.visualstudio.com/items?itemName=hediet.vscode-drawio)
- [Julia (Plotting, data processing)](https://marketplace.visualstudio.com/items?itemName=julialang.language-julia)
- Instead of Julia, Quarto also supports other languages (Python, R)


# Data Processing and Plotting using Julia

Quarto supports the generation of Jupyter notebooks from markdown files as an itermediate step when generating a document.
These notebooks can contain executable cells and these cells as well as their output *can* be part of the final document.
With that, we can create our plots directly in the document source from the most recent data.

Please refer to the official documentation for [setup instructions](https://quarto.org/docs/computations/julia.html#installation).

It is recommended to also install the `jupyter-cache` package to speed up document generation.


# Installing the ACM Template

We assume Quarto is already installed on the system.
Execute the following line to create a new project with the ACM template:

```
quarto use template quarto-journals/acm
```

You will have to provide a name for the document. We will use `example` in the following.
The command above will create a new directory `example` with several files and folders in there. The most important file for us is the `example.qmd`, which is the source code for our document.
We can render the template into a PDF with the following command:

```
quarto render example/example.qmd
```

How about creating a website from the same document?

```
quarto render example/example.qmd --to acm-html
```

Take a look at the provided template `example/example.qmd` to get an idea of cross-references, citations, and more.

An IEEE template is also available:

```
quarto use template gael-close/ieeetran
```

Note, that all templates are available on GitHub and can easily be forked and modified to your personal needs!
You can find a (incomplete) list of journal templates here: [https://github.com/quarto-journals](https://github.com/quarto-journals)

# CI/CD

An example `.gitlab-ci.yml` file can be found in this repository.
It contains rules to build a website and PDF from source using the IMT GitLab runner and deploy it on our GitLab instance.
The generated website can be found [here](https://mariusme.pages.git.uni-paderborn.de/quarto-getting-started/) and the sources [here](https://git.uni-paderborn.de/mariusme/quarto-getting-started) (depending on where you are reading this text right now).

