# Two Column Setup Example

This is a short example how to set up a two-column layout for the ACM template.

The following changes where made based on the default ACM template for Quarto.
Similar changes will be required for the IEEE 2-column layouts

### Install Quarto extensions

1. Install te ACM template: `quarto use template quarto-journals/acm`
2. Install Latex environments extension: `quarto add quarto-ext/latex-environment`

### Include the Latex environment

The subfolder already contains the latex environments in the folder `latex_includes`.
Add them to your project by extending the format section as follows:

```yaml
format:
  acm-pdf:
    include-in-header: 
      - latex_includes/fix-2-column-tables.tex 
    pdf-engine: pdflatex
```

### Add filters for Tale environments

Add the following lines at the end of the YAML section:

```yaml
filters:
   - latex-environment
environments: [tableenv, widetableenv]
```

### Change the ACM options

Uncomment and modify the following line within the acm-metadata section to select the 2-column layout:

```yaml
  acmart-options: acmtog
```

### Use te Filter for every table in the Markdown

You have to specify the included environments now for every table in the Markdown.
By using the environment `.tableenv` and `.widetableenv` we can specify if the table should spread accross a single column or both columns.

For single column, definee table like tis:

```
::: {.tableenv options="!h"}
: Frequency of Special Characters {#tbl-freq}

| Non-English or Math | Frequency   | Comments          |
|:-------------------:|:-----------:|:------------------|
| Ø                   | 1 in 1,000  | For Swedish names |
| $\pi$               | 1 in 5      | Common in math    |
| $                   | 4 in 5      | Used in business  |
| $\Psi^2_1$          | 1 in 40,000 | Unexplained usage |

:::
```

For two columns like this:

For single column, definee table like tis:

```
::: {.widetableenv options="!h"}
: Frequency of Special Characters {#tbl-freq}

| Non-English or Math | Frequency   | Comments          |
|:-------------------:|:-----------:|:------------------|
| Ø                   | 1 in 1,000  | For Swedish names |
| $\pi$               | 1 in 5      | Common in math    |
| $                   | 4 in 5      | Used in business  |
| $\Psi^2_1$          | 1 in 40,000 | Unexplained usage |

:::
```

Take a look into `test.qmd` to see these changes applied for the ACM template.

